@@ -140,7 +140,7 @@ def AutoAdjust(image, corners, s = 200, array_dimensions = (8,12)):
         for c in range(0,array_dimensions[1]): # loop over columns
             t = tiles[j]
             r1,c1 = corners[j]
-            m = remove_small_objects(t>.6, min_size =2000)
+            m = remove_small_objects(t>.6, min_size = 0.05*s**2)
             labels = label(m)
             if np.max(labels):
                 props = regionprops(labels)
@@ -265,7 +265,7 @@ def AutoCrop(file, sourcefolderpath, rotate = False,
 
     # -- Identify top and bottom
     bw = img>.5
-    bw = remove_small_objects(bw, min_size =1000)
+    bw = remove_small_objects(bw, min_size =0.025*s**2)
     mask = convex_hull_image(bw)
 
     y = np.sum(mask, axis = 1)
@@ -460,6 +460,7 @@ def EnhancedGridDisplay(image, corner, s, array_dimensions):
 
 def AutoCropTest(image, s = 200, array_dimensions = (8,12),adjust=True, display = False):
     '''
+    Cropping adjusted for test images included in package (ie image is already loaded as an array)
     Input: RGB or grayscale image of rectangular arrayed plate.
            parameter: plate height in pixels
            s side length of desired tiles in pixels
@@ -521,6 +522,7 @@ def AutoCropTest(image, s = 200, array_dimensions = (8,12),adjust=True, display
 def GridCropTest(image, A1_location = (500,500), s = 200, array_dimensions = (8,12), 
               adjust=True, display = False):
     '''
+    Cropping adjusted for test images included in package (ie image is already loaded as an array)
     input: image array
            expected dimensions of array of colonies on plate
            A1_location: estimate of center of pin location A1
@@ -546,8 +548,8 @@ def GridCropTest(image, A1_location = (500,500), s = 200, array_dimensions = (8,
     c1 = A1_location[1]
     c2 = c1 + (array_dimensions[1]- 1/2)*s*1.02
 
-    rps = np.linspace(r1,r2,8)
-    cps = np.linspace(c1,c2,12)
+    rps = np.linspace(r1,r2,array_dimensions[0])
+    cps = np.linspace(c1,c2,array_dimensions[1])
     
     corners = [None]*len(rps)*len(cps)
     j = 0
